@@ -43,11 +43,13 @@ from carla_backend import (
     PLUGIN_VST2,
     PLUGIN_VST3,
     PLUGIN_AU,
+    PLUGIN_JSFX,
     PLUGIN_DLS,
     PLUGIN_GIG,
     PLUGIN_SF2,
     PLUGIN_SFZ,
     PLUGIN_JACK,
+    PLUGIN_JSFX,
     PLUGIN_CATEGORY_NONE,
     PLUGIN_CATEGORY_SYNTH,
     PLUGIN_CATEGORY_DELAY,
@@ -84,6 +86,8 @@ def getPluginTypeAsString(ptype):
         return "VST3"
     if ptype == PLUGIN_AU:
         return "AU"
+    if ptype == PLUGIN_JSFX:
+        return "JSFX"
     if ptype == PLUGIN_DLS:
         return "DLS"
     if ptype == PLUGIN_GIG:
@@ -94,6 +98,8 @@ def getPluginTypeAsString(ptype):
         return "SFZ"
     if ptype == PLUGIN_JACK:
         return "JACK"
+    if ptype == PLUGIN_JSFX:
+        return "JSFX"
 
     print("getPluginTypeAsString(%i) - invalid type" % ptype)
     return "Unknown"
@@ -120,6 +126,8 @@ def getPluginTypeFromString(stype):
         return PLUGIN_VST3
     if stype in ("au", "audiounit"):
         return PLUGIN_AU
+    if stype == "jsfx":
+        return PLUGIN_JSFX
     if stype == "dls":
         return PLUGIN_DLS
     if stype == "gig":
@@ -130,6 +138,8 @@ def getPluginTypeFromString(stype):
         return PLUGIN_SFZ
     if stype == "jack":
         return PLUGIN_JACK
+    if stype == "jsfx":
+        return PLUGIN_JSFX
 
     print("getPluginTypeFromString(\"%s\") - invalid string type" % stype)
     return PLUGIN_NONE
@@ -327,9 +337,15 @@ class CarlaUtils():
         self.lib.carla_juce_cleanup.argtypes = None
         self.lib.carla_juce_cleanup.restype = None
 
+        self.lib.carla_get_desktop_scale_factor.argtypes = None
+        self.lib.carla_get_desktop_scale_factor.restype = c_double
+
         self.lib.carla_cocoa_get_window.argtypes = [c_uintptr]
         self.lib.carla_cocoa_get_window.restype = c_int
 
+        self.lib.carla_cocoa_set_transient_window_for.argtypes = [c_uintptr, c_uintptr]
+        self.lib.carla_cocoa_set_transient_window_for.restype = None
+
         self.lib.carla_x11_reparent_window.argtypes = [c_uintptr, c_uintptr]
         self.lib.carla_x11_reparent_window.restype = None
 
@@ -477,9 +493,15 @@ class CarlaUtils():
     def juce_cleanup(self):
         self.lib.carla_juce_cleanup()
 
+    def get_desktop_scale_factor(self):
+        return float(self.lib.carla_get_desktop_scale_factor())
+
     def cocoa_get_window(self, winId):
         return self.lib.carla_cocoa_get_window(winId)
 
+    def cocoa_set_transient_window_for(self, childWinId, parentWinId):
+        self.lib.carla_cocoa_set_transient_window_for(childWinId, parentWinId)
+
     def x11_reparent_window(self, winId1, winId2):
         self.lib.carla_x11_reparent_window(winId1, winId2)
 
